﻿//	『昼夜逆転』工作室	http://jsdiy.web.fc2.com
//	FT232 7セグ制御ライブラリ デモプログラム
//	2011/11/10

using System;
using System.Threading;		//Sleep
using FT232_7Seg4Lib;

namespace ft232r7seg4
{
	class Program
	{
		private static SegCtrl segled;
		
		static void Main(string[] args)
		{
			//ピンアサインを設定する
			PortMgr pm = new PortMgr();
			
			//ブレッドボードバージョンでのピンアサイン（白黒の回路図）
			//SRegPin.P1～P8とSegLedPin.A～DPの対応はデフォルト値の通りなのでSetSRegPort()は省略
			pm.SetSRegCtrl(FtPin.D0, FtPin.D4, FtPin.D2);
			pm.SetSegLedDigit(FtPin.D6, FtPin.D5, FtPin.D7, FtPin.D1);
			
			/*	基板バージョンでのピンアサイン（カラーの配線図）
			pm.SetSRegPort(SRegPin.P8, SegLedPin.A);
			pm.SetSRegPort(SRegPin.P1, SegLedPin.B);
			pm.SetSRegPort(SRegPin.P3, SegLedPin.C);
			pm.SetSRegPort(SRegPin.P5, SegLedPin.D);
			pm.SetSRegPort(SRegPin.P6, SegLedPin.E);
			pm.SetSRegPort(SRegPin.P7, SegLedPin.F);
			pm.SetSRegPort(SRegPin.P2, SegLedPin.G);
			pm.SetSRegPort(SRegPin.P4, SegLedPin.DP);
			pm.SetSRegCtrl(FtPin.D0, FtPin.D4, FtPin.D2);
			pm.SetSegLedDigit(FtPin.D6, FtPin.D5, FtPin.D7, FtPin.D1);
			*/
			
			//7セグ制御オブジェクトを生成する
			segled = new SegCtrl(pm);
			
			//丁寧
			if (!segled.Start(true))
			{
				Console.WriteLine("FT232 ready...");
				if (!segled.Start()) AppClose(segled.EMessage, segled.ECode);
			}
			//簡素
			//if (!segled.Start()) AppClose(segled.EMessage, segled.ECode);
			
			Console.WriteLine("7Seg start");
			Console.WriteLine("[1][2][3][4]の表示から、何かキーを押すごとに次の動作をします。" + Environment.NewLine +
				"→2桁目のDPが3回点滅したあと、左から3桁目が消える。" + Environment.NewLine +
				"→[ ][-][5.][6]の表示。" + Environment.NewLine +
				"→[0.][9][8][7]の表示。" + Environment.NewLine +
				"→[ ][Y][e][S]の表示。" + Environment.NewLine +
				"→[a][b.][c][d.]の表示。");
			
			//1桁ずつで[1][2][3][4]と表示する
			segled.PutNumber(1, 0);
			segled.PutNumber(2, 1);
			segled.PutNumber(3, 2);
			segled.PutNumber(4, 3);
			Console.ReadKey();
			if (segled.IsError) AppClose(segled.EMessage, segled.ECode);
			//仮にFT232モジュールを引っこ抜いてキー入力すると、エラーが発生してアプリは終了する。
			
			//2桁目のDPが3回点滅する
			for (int i = 0; i < 3; i++)
			{
				segled.PutSegDP(true, 1);
				Thread.Sleep(500);
				segled.PutSegDP(false, 1);
				Thread.Sleep(500);
			}
			
			segled.Cls(2);	//左から3桁目が消える
			Console.ReadKey();
			
			segled.PutNumber(-5.6, 1);	//[ ][-][5.][6]
			Console.ReadKey();
			
			segled.PutNumber(.987, 0);	//[0.][9][8][7]
			Console.ReadKey();
			
			segled.PutString(" Yes", 0);	//[ ][Y][e][S]
			Console.ReadKey();
			//小文字's'のセグメントパターンは定義されていないので大文字'S'が表示される。
			//1桁目は直前の[0.]が残るのではなく空白文字そのものが表示される。
			
			segled.PutString("ab.cd.ef.g", 0);	//[a][b.][c][d.]
			Console.ReadKey();
			if (segled.IsError) AppClose(segled.EMessage, segled.ECode);
			//長い文字列は、はみ出る分が無視される。
			//エラーにはならないので、このエラー処理は実行されない。
			
			AppClose();
		}
		
		//アプリ終了
		private static void AppClose() { AppClose(null, 0); }
		private static void AppClose(string mes, int exitCode)
		{
			//7セグ制御オブジェクトを破棄する
			if (segled != null) segled.Dispose();
			
			//終了メッセージを表示する
			if (mes != null) Console.WriteLine(mes + Environment.NewLine);
			
			Console.WriteLine("Press any key.");
			Console.ReadKey();
			Environment.Exit(exitCode);
		}
	}
}
